@@ -151,9 +151,17 @@
     Updated by      Richard Gooch   2-OCT-1997: Use paths.h instead of my own
   hardcoded values.
 
-    Last updated by Richard Gooch   3-OCT-1997: Reset timing interval when
+    Updated by      Richard Gooch   3-OCT-1997: Reset timing interval when
   SIGUSR2 is caught or when mail is read to be processed.
 
+    Updated by      Richard Gooch   8-OCT-1997: Supported $env as USERID
+  configuration option.
+
+    Last updated by Richard Gooch   9-OCT-1997: Made use of new function
+  <st_expr_expand>.
+
+    Last updated by Richard Gooch   21-OCT-1997: Conditionally include paths.h
+
 
 */
 #include <stdio.h>
@@ -173,7 +181,9 @@
 #endif
 #include <string.h>
 #include <errno.h>
-#include <paths.h>
+#ifndef NO_PATH_H
+#  include <paths.h>
+#endif
 #include <pgpsendmail.h>
 #include <version.h>
 
@@ -216,6 +226,8 @@ static flag caught_sigio = FALSE;
 static char incoming_spool[STRING_LENGTH];
 static char outgoing_spool[STRING_LENGTH];
 static char my_userid[STRING_LENGTH];
+static char logfile[STRING_LENGTH];
+static char hostname[STRING_LENGTH];
 
 
 /*  Code for  myexit  must come first.  */
@@ -265,7 +277,6 @@ char *envp[];
     struct sigaction new_action;
     struct rlimit rlp;
     struct stat statbuf;
-    char hostname[STRING_LENGTH];
     char pid_filename[STRING_LENGTH];
     char inpipe_filename[STRING_LENGTH];
     char outpipe_filename[STRING_LENGTH];
@@ -284,6 +295,7 @@ char *envp[];
     extern char my_userid[STRING_LENGTH];
     extern char incoming_spool[STRING_LENGTH];
     extern char outgoing_spool[STRING_LENGTH];
+    extern char hostname[STRING_LENGTH];
     static char usage_string[] =
     "Usage:\tpgpdaemon [-mailwait] [-detach] [-pgppath <path>]";
     extern char *sys_errlist[];
@@ -402,13 +414,13 @@ char *envp[];
 	fprintf (stderr, "Could not find file: \"%s\"\t%s\n", txt, ERRSTRING);
 	myexit (RV_UNDEF_ERROR);
     }
-    read_config (pgppath, &mailwait, &max_interval, check_mail);
     if (gethostname (hostname, STRING_LENGTH - 1) != 0)
     {
 	fprintf (stderr, "Error getting hostname\t%s\n", ERRSTRING);
 	myexit (RV_SYS_ERROR);
     }
     hostname[STRING_LENGTH - 1] = '\0';
+    read_config (pgppath, &mailwait, &max_interval, check_mail);
     /*  Worry about communication files  */
     sprintf (pid_filename, "%s/.pgpd.PID.%s", pgppath, hostname);
     sprintf (inpipe_filename, "%s/.pgpd.input.%s", pgppath, hostname);
@@ -485,11 +497,12 @@ char *envp[];
     fprintf ( fp, "%d\n", getpid () );
     fclose (fp);
     /*  Open logfile  */
-    sprintf (txt, "%s/PGPdaemon.log.%s", pgppath, hostname);
-    if ( ( fd = open (txt, O_WRONLY | O_CREAT | O_APPEND, S_IRUSR | S_IWUSR) )
+    if ( ( fd = open (logfile,
+		      O_WRONLY | O_CREAT | O_APPEND, S_IRUSR | S_IWUSR) )
 	< 0 )
     {
-	fprintf (stderr, "Error opening file: \"%s\"\t%s\n", txt, ERRSTRING);
+	fprintf (stderr, "Error opening file: \"%s\"\t%s\n", logfile,
+		 ERRSTRING);
 	myexit (RV_UNDEF_ERROR);
     }
     if (dup2 (fd, 1) == -1)
@@ -1519,6 +1532,7 @@ flag check_mail;
     extern char my_userid[STRING_LENGTH];
     extern char incoming_spool[STRING_LENGTH];
     extern char outgoing_spool[STRING_LENGTH];
+    extern char logfile[STRING_LENGTH];
     extern char *sys_errlist[];
 
     sprintf (config_filename, "%s/PGPdaemon.config", pgppath);
@@ -1532,6 +1546,7 @@ flag check_mail;
     m_clear (my_userid, STRING_LENGTH);
     m_clear (incoming_spool, STRING_LENGTH);
     m_clear (outgoing_spool, STRING_LENGTH);
+    m_clear (logfile, STRING_LENGTH);
     while (fgets (txt, STRING_LENGTH - 1, fp) != NULL)
     {
 	/*  Strip newline  */
@@ -1569,6 +1584,7 @@ flag check_mail;
 		myexit (RV_BAD_DATA);
 	    }
 	}
+	else if (strcmp (keyword, "LOG_FILE") == 0) strcpy (logfile, rest);
 	else
 	{
 	    fprintf (stderr, "Illegal config line: \"%s\"\n", txt);
@@ -1581,6 +1597,16 @@ flag check_mail;
 	fprintf (stderr, "No USERID specified in config file\n");
 	myexit (RV_BAD_DATA);
     }
+    if (my_userid[0] == '$')
+    {
+	if ( ( tmp = getenv (my_userid + 1) ) == NULL )
+	{
+	    fprintf (stderr, "Environment variable: \"%s\" not found\n",
+		     my_userid + 1);
+	    myexit (RV_BAD_DATA);
+	}
+	strcpy (my_userid, tmp);
+    }
     if (incoming_spool[0] == '\0')
     {
 	/*  No existing spool directory named  */
@@ -1600,14 +1626,7 @@ flag check_mail;
 	strcat (incoming_spool, "/");
 	strcat ( incoming_spool, getenv ("USER") );
     }
-    if (strncmp (incoming_spool, "~/", 2) == 0)
-    {
-	/*  Expand leading "~/"  */
-	strcpy ( txt, getenv ("HOME") );
-	strcat (txt, "/");
-	strcat (txt, incoming_spool + 2);
-	strcpy (incoming_spool, txt);
-    }
+    st_expr_expand (incoming_spool, STRING_LENGTH, incoming_spool, NULL);
     /*  Extract spool directory  */
     strcpy (txt, incoming_spool);
     if ( ( tmp = strrchr (txt, '/') ) == NULL )
@@ -1635,20 +1654,17 @@ flag check_mail;
     }
     if (outgoing_spool[0] == '\0')
     {
-	sprintf ( outgoing_spool, "%s/decrypted-mail",
-			getenv ("HOME") );
+	sprintf ( outgoing_spool, "%s/decrypted-mail", getenv ("HOME") );
     }
     else
     {
-	if (strncmp (outgoing_spool, "~/", 2) == 0)
-	{
-	    /*  Expand leading "~/"  */
-	    strcpy ( txt, getenv ("HOME") );
-	    strcat (txt, "/");
-	    strcat (txt, outgoing_spool + 2);
-	    strcpy (outgoing_spool, txt);
-	}
+	st_expr_expand (outgoing_spool, STRING_LENGTH, outgoing_spool, NULL);
     }
+    if (logfile[0] == '\0')
+    {
+	sprintf (txt, "%s/PGPdaemon.log.%s", pgppath, hostname);
+    }
+    else st_expr_expand (logfile, STRING_LENGTH, logfile, NULL);
 }   /*  End Function read_config  */
 
 static flag write_secring ()
