@@ -117,9 +117,14 @@
     Updated by      Richard Gooch   3-OCT-1997: Open config file only once.
   Add +language=en option to PGP.
 
-    Last updated by Richard Gooch   4-OCT-1997: Added "HEADER_TAIL_FILE" and
+    Updated by      Richard Gooch   4-OCT-1997: Added "HEADER_TAIL_FILE" and
   "BODY_HEAD_FILE" options. Attempt to wake PGPdaemon when message sent.
 
+    Updated by      Richard Gooch   9-OCT-1997: Restored configurability of
+  real sendmail location (else mere mortals would be hosed).
+
+    Last updated by Richard Gooch   21-OCT-1997: Conditionally include paths.h
+
 
 */
 #include <stdio.h>
@@ -133,7 +138,9 @@
 #include <fcntl.h>
 #include <string.h>
 #include <errno.h>
-#include <paths.h>
+#ifndef NO_PATH_H
+#  include <paths.h>
+#endif
 #include <pgpsendmail.h>
 #include <version.h>
 
@@ -212,7 +219,11 @@ char *envp[];
     info.scan_to = TRUE;
     info.scan_cc = TRUE;
     info.scan_bcc = TRUE;
+#ifdef USE_OLD_SENDMAIL
+    strcpy (real_sendmail, _PATH_SENDMAIL);
+#else
     sprintf (real_sendmail, "%s.real", _PATH_SENDMAIL);
+#endif
     if (access (real_sendmail, X_OK) != 0)
     {
 	fprintf (stderr, "File: \"%s\" is not executable\t%s\n",
